# Ph4 Sensirion Gas Index algorithm in Python

Port of the [Sensirion Gas Index Algorithm](https://github.com/Sensirion/gas-index-algorithm/) to pure Python.
From the commit [31c1108f716](https://github.com/Sensirion/gas-index-algorithm/commit/31c1108f71633bc8664a2e045b1b4fa2b75445e9)

## Development

Install pre-commit hooks defined by `.pre-commit-config.yaml`

```shell
pip3 install -U pre-commit
pre-commit install
```

Auto fix
```shell
pre-commit run --all-files
```

Plugin version update
```shell
pre-commit autoupdate
```
